Index: trunk/gli/classes/feedback.properties
===================================================================
--- trunk/gli/classes/feedback.properties	(revision 8977)
+++ trunk/gli/classes/feedback.properties	(revision 8978)
@@ -221,5 +221,5 @@
 Separator=Separator
 NoComponent=No Component (it's a null object)
-TitlePane=Metal Title Pane (Platform dependant)
+TitlePane=Metal Title Pane (Platform dependent)
 ToolTipText=ToolTipText
 Feedback=Feedback
Index: trunk/gli/makegli.bat
===================================================================
--- trunk/gli/makegli.bat	(revision 8977)
+++ trunk/gli/makegli.bat	(revision 8978)
@@ -141,5 +141,5 @@
 if "%1" == "" goto makeAll
     :: If a file has been specified as a command-line argument, just compile that file
-    if "%GLILANG%" == "en" echo Compiling %1 and dependant classes...
+    if "%GLILANG%" == "en" echo Compiling %1 and dependent classes...
     if "%GLILANG%" == "es" echo Compilando %1 y clases dependientes...
     if "%GLILANG%" == "fr" echo Compilation de %1 et des classes dpendantes,,,
Index: trunk/gli/makegli.sh
===================================================================
--- trunk/gli/makegli.sh	(revision 8977)
+++ trunk/gli/makegli.sh	(revision 8978)
@@ -126,5 +126,5 @@
 	echo "ëÏÍÐÉÌÉÒÏ×ÁÎÉÅ $* É ÚÁ×ÉÓÉÍÙÅ ËÌÁÓÓÙ..."
     else
-	echo "Compiling $* and dependant classes..."
+	echo "Compiling $* and dependent classes..."
     fi
 
Index: trunk/gli/metadata/dublin.mds
===================================================================
--- trunk/gli/metadata/dublin.mds	(revision 8977)
+++ trunk/gli/metadata/dublin.mds	(revision 8978)
@@ -19,5 +19,5 @@
             name               CDATA #REQUIRED
 	    namespace          CDATA #REQUIRED
-	    language_dependant CDATA "">
+	    language_dependent CDATA "">
 
   <!-- The name of a metadata set. Is language specific. -->
Index: trunk/gli/metadata/nzgls.mds
===================================================================
--- trunk/gli/metadata/nzgls.mds	(revision 8977)
+++ trunk/gli/metadata/nzgls.mds	(revision 8978)
@@ -19,5 +19,5 @@
             name               CDATA #REQUIRED
 	    namespace          CDATA #REQUIRED
-	    language_dependant CDATA "">
+	    language_dependent CDATA "">
 
   <!-- The name of a metadata set. Is language specific. -->
Index: trunk/gli/metadata/qdublin.mds
===================================================================
--- trunk/gli/metadata/qdublin.mds	(revision 8977)
+++ trunk/gli/metadata/qdublin.mds	(revision 8978)
@@ -19,5 +19,5 @@
             name               CDATA #REQUIRED
 	    namespace          CDATA #REQUIRED
-	    language_dependant CDATA "">
+	    language_dependent CDATA "">
 
   <!-- The name of a metadata set. Is language specific. -->
@@ -59,5 +59,5 @@
             restricted (true|false) "false">
 ]>
-<MetadataSet contact="dcmi-feedback@dublincore.org" creator="Dublin Core Metadata Initiative" family="Dublin Core" language_dependant="identifier, definition, comment" lastchanged="Tue Jun 04 10:35:30 2002 - jmt12 on blackbird" namespace="dc">
+<MetadataSet contact="dcmi-feedback@dublincore.org" creator="Dublin Core Metadata Initiative" family="Dublin Core" language_dependent="identifier, definition, comment" lastchanged="Tue Jun 04 10:35:30 2002 - jmt12 on blackbird" namespace="dc">
     <!-- English Version sourced from http://www.dublincore.org/documents/dces/ -->
     <SetLanguage code="en">
Index: trunk/gli/metadata/rfc1807.mds
===================================================================
--- trunk/gli/metadata/rfc1807.mds	(revision 8977)
+++ trunk/gli/metadata/rfc1807.mds	(revision 8978)
@@ -19,5 +19,5 @@
             name               CDATA #REQUIRED
 	    namespace          CDATA #REQUIRED
-	    language_dependant CDATA "">
+	    language_dependent CDATA "">
 
   <!-- The name of a metadata set. Is language specific. -->
Index: trunk/gli/src/org/greenstone/gatherer/gems/ComboArea.java
===================================================================
--- trunk/gli/src/org/greenstone/gatherer/gems/ComboArea.java	(revision 8977)
+++ trunk/gli/src/org/greenstone/gatherer/gems/ComboArea.java	(revision 8978)
@@ -188,5 +188,5 @@
 		temp = (JLabel) super.getListCellRendererComponent(list, "", index, isSelected, cellHasFocus);
 	    }
-				// Colouring should be the same as the dependant we are based on.
+				// Colouring should be the same as the dependent we are based on.
 	    if(isSelected) {
 		temp.setBackground(text_area.getSelectionColor());
Index: trunk/gli/src/org/greenstone/gatherer/gems/ElementWrapper.java
===================================================================
--- trunk/gli/src/org/greenstone/gatherer/gems/ElementWrapper.java	(revision 8977)
+++ trunk/gli/src/org/greenstone/gatherer/gems/ElementWrapper.java	(revision 8978)
@@ -205,5 +205,5 @@
 	return element;
     }
-    /** Retrieve the identity of this element (not necessary the same as this elements name). Identity is language and locale dependant.
+    /** Retrieve the identity of this element (not necessary the same as this elements name). Identity is language and locale dependent.
      * @return The identity as a <strong>String</strong>.
      * @see org.greenstone.gatherer.msm.MSMUtils
Index: trunk/gli/src/org/greenstone/gatherer/gems/MetadataSet.java
===================================================================
--- trunk/gli/src/org/greenstone/gatherer/gems/MetadataSet.java	(revision 8977)
+++ trunk/gli/src/org/greenstone/gatherer/gems/MetadataSet.java	(revision 8978)
@@ -617,5 +617,5 @@
     }
 
-    /** This method retrieves the required attribute from the Metadata Set, typically it's name or it's description. Note that this method is language dependant, and moreover supports both legacy metadata sets and the new sets optimized for multiple languages.
+    /** This method retrieves the required attribute from the Metadata Set, typically it's name or it's description. Note that this method is language dependent, and moreover supports both legacy metadata sets and the new sets optimized for multiple languages.
      * @param element_name the name of the type of element the required information is in as a String
      * @param default_string the value to return if no such element is found also as a String
Index: trunk/gli/src/org/greenstone/gatherer/util/StaticStrings.java
===================================================================
--- trunk/gli/src/org/greenstone/gatherer/util/StaticStrings.java	(revision 8977)
+++ trunk/gli/src/org/greenstone/gatherer/util/StaticStrings.java	(revision 8978)
@@ -142,5 +142,5 @@
     static final public String LANGUAGE_DEFAULT_STR                       = "defaultlanguage";
     static final public String LANGUAGE_STR                               = "language";
-    static final public String LANGUAGEDEPENDANT_ATTRIBUTE                = "language_dependent";
+    static final public String LANGUAGEDEPENDENT_ATTRIBUTE                = "language_dependent";
     static final public String LANGUAGES_ELEMENT                          = "Languages";
     static final public String LANGUAGES_STR                              = "languages";

Index: trunk/gli/src/org/greenstone/gatherer/gems/MSMUtils.java
===================================================================
--- trunk/gli/src/org/greenstone/gatherer/gems/MSMUtils.java	(revision 8977)
+++ trunk/gli/src/org/greenstone/gatherer/gems/MSMUtils.java	(revision 8978)
@@ -75,10 +75,10 @@
     } 
 
     /** Method to add an attribute element to the given element. This method makes use of the language_dependant attribute of the document to not only determine if the attribute is language dependant, but also to see whether a Language element should be created if doesn't already exist.
      * @param element_element the Element to add the attribute element to
      * @param attribute_name_str the name of the new attribute to add as a String
      * @param language_code_str the two letter code String of the language this attribute is to be added as
      * @param value_str the String to be assigned as the attribute elements value
-     * @see org.greenstone.gatherer.msm.MSMUtils#isAttributeLanguageDependant
+     * @see org.greenstone.gatherer.msm.MSMUtils#isAttributeLanguageDependent
      * @see org.greenstone.gatherer.msm.MSMUtils#setValue(Element, String)
      * @see org.greenstone.gatherer.util.StaticStrings#ATTRIBUTE_ELEMENT
@@ -96,5 +96,5 @@
 
 	// Start off by determining if we have to add this node in the new multilingual optimized way
-	if(isAttributeLanguageDependant(document, attribute_name_str)) {
+	if(isAttributeLanguageDependent(document, attribute_name_str)) {
 	    boolean found = false;
 	    // Try to retrieve a language element for the given language code
@@ -428,5 +428,5 @@
      * @param language_code_str the two letter code String indicating the desired language
      * @see org.greenstone.gatherer.msm.MSMUtils#getValue
-     * @see org.greenstone.gatherer.msm.MSMUtils#isAttributeLanguageDependant
+     * @see org.greenstone.gatherer.msm.MSMUtils#isAttributeLanguageDependent
      * @see org.greenstone.gatherer.util.StaticStrings#ATTRIBUTE_ELEMENT
      * @see org.greenstone.gatherer.util.StaticStrings#CODE_ATTRIBUTE
@@ -441,5 +441,5 @@
 	Document document = element_element.getOwnerDocument();
 	// Determine if the attribute is language specific
-	if(isAttributeLanguageDependant(document, attribute_name_str)) {
+	if(isAttributeLanguageDependent(document, attribute_name_str)) {
 	    NodeList language_elements = element_element.getElementsByTagName(StaticStrings.LANGUAGE_ELEMENT);
 	    for(int i = 0; !found && i < language_elements.getLength(); i++) {
@@ -738,11 +738,11 @@
      * @param document the Document for which we wish to check the language requirements
      * @param attribute_name_str the name of the attribute we a testing as a String
-     * @see org.greenstone.gatherer.util.StaticStrings#LANGUAGEDEPENDANT_ATTRIBUTE
+     * @see org.greenstone.gatherer.util.StaticStrings#LANGUAGEDEPENDENT_ATTRIBUTE
      * Modified by Matthew Whyte 4/02/05
      */
-    static private boolean isAttributeLanguageDependant(Document document, String attribute_name_str)
+    static private boolean isAttributeLanguageDependent(Document document, String attribute_name_str)
     {
 	//gives a list of comma seperated language specific attributes.
-	String language_specific_attributes = document.getDocumentElement().getAttribute(StaticStrings.LANGUAGEDEPENDANT_ATTRIBUTE).toLowerCase();
+	String language_specific_attributes = document.getDocumentElement().getAttribute(StaticStrings.LANGUAGEDEPENDENT_ATTRIBUTE).toLowerCase();
 	//System.err.println("lang_specific: " + language_specific_attributes); //debug
 
@@ -759,13 +759,13 @@
     }
 
     /** Determine if the given document is a legacy MDS or a new multilingual one. The easiest way to tell is whether there is a language_dependant attribute in the document element.
      * @param document the Document to test
      * @return true if this is an old mds, false otherwise
-     * @see org.greenstone.gatherer.util.StaticStrings#LANGUAGEDEPENDANT_ATTRIBUTE
+     * @see org.greenstone.gatherer.util.StaticStrings#LANGUAGEDEPENDENT_ATTRIBUTE
      * @see org.greenstone.gatherer.util.StaticStrings#EMPTY_STR
      */
     static private boolean isLegacyMDS(Document document) {
-	///ystem.err.println("isLegacyMDS(): l_d = " + document.getDocumentElement().getAttribute(StaticStrings.LANGUAGEDEPENDANT_ATTRIBUTE));
-	return (document.getDocumentElement().getAttribute(StaticStrings.LANGUAGEDEPENDANT_ATTRIBUTE)).equals(StaticStrings.EMPTY_STR);
+	///ystem.err.println("isLegacyMDS(): l_d = " + document.getDocumentElement().getAttribute(StaticStrings.LANGUAGEDEPENDENT_ATTRIBUTE));
+	return (document.getDocumentElement().getAttribute(StaticStrings.LANGUAGEDEPENDENT_ATTRIBUTE)).equals(StaticStrings.EMPTY_STR);
     }
 
@@ -809,5 +809,5 @@
      * @param value_str the value String which also must match before we remove anything
      * @return true if the desired attribute was successfully found and removed, false otherwise
-     * @see org.greenstone.gatherer.msm.MSMUtils#isAttributeLanguageDependant
+     * @see org.greenstone.gatherer.msm.MSMUtils#isAttributeLanguageDependent
      * @see org.greenstone.gatherer.msm.MSMUtils#getValue(Node)
      * @see org.greenstone.gatherer.util.StaticStrings#ATTRIBUTE_ELEMENT
@@ -820,5 +820,5 @@
 	//Determine the if this is one of the language specific attributes.
 	//This can sometimes give a false result, if an attribute is made language specific half way through creation of a metadata set (or vice versa).
-	if(isAttributeLanguageDependant(element_element.getOwnerDocument(), attribute_name_str))
+	if(isAttributeLanguageDependent(element_element.getOwnerDocument(), attribute_name_str))
 	    {
 		/*
@@ -75,10 +75,10 @@
     } 
 
-    /** Method to add an attribute element to the given element. This method makes use of the language_dependant attribute of the document to not only determine if the attribute is language dependant, but also to see whether a Language element should be created if doesn't already exist.
+    /** Method to add an attribute element to the given element. This method makes use of the language_dependent attribute of the document to not only determine if the attribute is language dependent, but also to see whether a Language element should be created if doesn't already exist.
      * @param element_element the Element to add the attribute element to
      * @param attribute_name_str the name of the new attribute to add as a String
@@ -759,13 +759,13 @@
     }
 
-    /** Determine if the given document is a legacy MDS or a new multilingual one. The easiest way to tell is whether there is a language_dependant attribute in the document element.
+    /** Determine if the given document is a legacy MDS or a new multilingual one. The easiest way to tell is whether there is a language_dependent attribute in the document element.
      * @param document the Document to test
      * @return true if this is an old mds, false otherwise